@@ -1,14 +1,13 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta
+from trytond.pool import PoolMeta, Pool
 
 
 __all__ = ['Company']
-__metaclass__ = PoolMeta
 
 
-class Company:
+class Company(metaclass=PoolMeta):
     __name__ = 'company.company'
 
     hours_per_work_day = fields.Float("Hours per Work Day", required=True)
@@ -31,3 +30,10 @@ class Company:
     @staticmethod
     def default_hours_per_work_year():
         return 1920
+
+    @classmethod
+    def write(cls, *args):
+        pool = Pool()
+        User = pool.get('res.user')
+        super(Company, cls).write(*args)
+        User._get_preferences_cache.clear()
